var StorageBox = function()
{
	var box = {};
	var debug = 0;
	
	var nofBoxesIsValid = true;
	var lastBox;
	var newBoxes;
	
	// Page initialization
	box.initPage = function()
	{
		// Step 1
		Events.addEventHandler('step-1', 'wizard-validate', box.validateStep1);
		Events.addEventHandler('numberOfBoxes', 'keypress', Events.integerOnly);
		Events.addEventHandler('numberOfBoxes', 'blur', box.nofBoxesOnChange);

		// Step 2
		Events.addEventHandler('step-2', 'wizard-initialize', box.initializeStep2);
		
		// Navigation
		Buttons.addClickHandler('gocancel', Wizard.cancelWizard);
		Buttons.addClickHandler('gorestart', Wizard.restartWizard);
		Buttons.addClickHandler('gonext', Wizard.goNextOnClick);
		Buttons.addClickHandler('goregister', Wizard.goRegister);
		Buttons.addClickHandler('godownload', box.downloadLabels);
		
		
		// Final registration
		Events.addEventHandler('wizard', 'wizard-submit', box.submit);

		// Load last storage box
		var url = '../SpecimenTubeRegistration.servlet?ID='+App.getSessionId();
		url += '&cmd=GetLastExistingSpBox'
		Wizard.showLoadingAnimation('Loading existing storage box...');
		Wizard.asyncJsonRequest(url, box.lastBoxLoaded);
	}

	box.lastBoxLoaded = function(response)
	{
		lastBox = response.lastBox;
		var counts = response.counts;
		
		if (!lastBox) 
		{
			Wizard.setFatalError('Could not find any existing storage box.');
			return;
		}
		
		Doc.element('lastBox').innerHTML = Strings.encodeTags(lastBox.name) + ' (' + lastBox.freeWells + ' free wells)';
		Doc.element('emptyBoxes').innerHTML = counts['empty-storage-boxes'] || '-';
		Doc.show('step-1');
		Doc.show('gonext');
	}
	
	box.validateStep1 = function(event)
	{
		var frm = document.forms['reggie'];
		if (!nofBoxesIsValid) event.preventDefault();
	}
	
	box.nofBoxesOnChange = function()
	{
		nofBoxesIsValid = false;

		var frm = document.forms['reggie'];
		var nofBoxes = frm.numberOfBoxes.value;
		
		if (nofBoxes == '')
		{
			Wizard.setInputStatus('numberOfBoxes', 'invalid', 'Missing');
			return;
		}
		if (parseInt(nofBoxes) < 1)
		{
			Wizard.setInputStatus('numberOfBoxes', 'invalid', 'Must be at least 1');
			return;
		}
		if (parseInt(nofBoxes) > 99)
		{
			Wizard.setInputStatus('numberOfBoxes', 'invalid', 'Must not be greater than 99');
			return;
		}
		Wizard.setInputStatus('numberOfBoxes', 'valid');
		nofBoxesIsValid = true; 
	}

	box.initializeStep2 = function()
	{
		var frm = document.forms['reggie'];
		var nofBoxes = parseInt(frm.numberOfBoxes.value);
		
		var startNo = parseInt(lastBox.name.substring(2)) + 1;
		var endNo = startNo+nofBoxes;
		
		var html = '';
		var boxPrefixes = ['Sp', 'Lys', 'RNA', 'DNA', 'FT'];
		newBoxes = [];
		for (var boxNo = startNo; boxNo < endNo; boxNo++)
		{
			var zeroPad = '';
			if (boxNo < 10) zeroPad = '00';
			if (boxNo < 100) zeroPad = '0';
			
			html += '<tr>';
			for (var prefixNo = 0; prefixNo < boxPrefixes.length; prefixNo++)
			{
				var boxName = boxPrefixes[prefixNo]+zeroPad+boxNo;
				newBoxes[newBoxes.length] = boxName;
				html += '<td>'+boxName+'</td>';
			}
			html += '</tr>';
		}
		Doc.element('new-boxes').innerHTML = html;
		
		Wizard.setCurrentStep(2);
		Doc.show('goregister');
		Doc.show('gocancel');
		Doc.show('godownload');
		Wizard.showGoNextConfirmation(true, 'I have downloaded the label file');
	}
	
	box.downloadLabels = function()
	{
		Wizard.hideGoNextConfirmation();
		var url = '../SpecimenTubeRegistration.servlet?ID='+App.getSessionId();
		url += '&cmd=GetStorageBoxLabels';
		url += '&boxes='+newBoxes.join(',');
		window.open(url);
	}

	box.submit = function()
	{
		var frm = document.forms['reggie'];
		
		var nofBoxes = parseInt(frm.numberOfBoxes.value);

		var submitInfo = {};
		submitInfo.lastBox = lastBox.id;
		submitInfo.nofBoxes = nofBoxes;

		var url = '../SpecimenTubeRegistration.servlet?ID='+App.getSessionId();
		url += '&cmd=CreateStorageBoxes';
		Wizard.showLoadingAnimation('Performing registration...');
		Wizard.asyncJsonRequest(url, box.submissionResults, 'POST', JSON.stringify(submitInfo));
	}
	
	box.submissionResults = function(response)
	{
		Wizard.showFinalMessage(response.messages);
		Doc.show('gorestart');
	}


	return box;
}();

Doc.onLoad(StorageBox.initPage);

